@@ -141,7 +141,7 @@ Crypt::TEA_PP - Pure Perl Implementation of the Tiny Encryption Algorithm
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -193,8 +193,9 @@ Decrypts blocksize() bytes of $data and returns the corresponding plaintext.
 
 =head1 SEE ALSO
 
-=for :list * L<http://www.vader.brad.ac.uk/tea/tea.shtml>
-* L<Crypt::CBC>
+L<http://www.vader.brad.ac.uk/tea/tea.shtml>
+
+L<Crypt::CBC>
 
 =head1 AUTHOR
 
